'use strict'

exports.__esModule = true
exports.checkGraphQLSchema = void 0

var _graphql = require('graphql')

var _createHttpError = require('./createHttpError.js')

const checkGraphQLSchema = (schema, errorMessagePrefix) => {
  if (!(schema instanceof _graphql.GraphQLSchema))
    throw (0, _createHttpError.createHttpError)(
      `${errorMessagePrefix} GraphQL schema must be a \`GraphQLSchema\` instance.`
    )
  const schemaValidationErrors = (0, _graphql.validateSchema)(schema)
  if (schemaValidationErrors.length)
    throw (0, _createHttpError.createHttpError)(
      `${errorMessagePrefix} has GraphQL schema validation errors.`,
      {
        graphqlErrors: schemaValidationErrors
      }
    )
}

exports.checkGraphQLSchema = checkGraphQLSchema
